﻿using System;
using System.Linq;
using Infragistics.Documents.Excel;

namespace SpreadsheetMinimalPrototype
{
	internal class SheetStyle
	{
		private const int FONT_HEIGHT_MULTIPLIER = 20;
		private const double PX_TO_PT_MULTIPLIER = 0.74999943307122;
		private const int FONT_HEIGHT_TO_ROW_HEIGHT_OFFSET = 60;
		
		private readonly string mFontName;
		private readonly int mFontHeightTwips;

		public SheetStyle(string fontName, double fontSizePx)
		{
			mFontName = fontName;
			mFontHeightTwips = ConvertToFontHeight(fontSizePx);
		}

		public Workbook ApplyTo(Workbook workbook)
		{
			ApplyTo(workbook.Styles.NormalStyle);
			ApplyTo(workbook.Worksheets);

			return workbook;
		}

		private static int ConvertToFontHeight(double fontSizePx) =>
			Convert.ToInt32(fontSizePx * PX_TO_PT_MULTIPLIER * FONT_HEIGHT_MULTIPLIER);

		private void ApplyTo(WorkbookStyle style) => ApplyTo(style.StyleFormat.Font);

		private void ApplyTo(IWorkbookFont font)
		{
			font.Name = mFontName;
			font.Height = mFontHeightTwips;
		}

		private void ApplyTo(WorksheetCollection sheets)
		{
			foreach (var sheet in sheets)
			{
				sheet.DefaultRowHeight = mFontHeightTwips + FONT_HEIGHT_TO_ROW_HEIGHT_OFFSET;

				// Problem location causing to change scrollbar maximum value:
				if (sheet.Rows.Any())
					sheet.Rows[0].CellFormat.Font.Height = mFontHeightTwips;
			}
		}
	}
}
